#[repr(i32)]pub enum FlowControlLimitExceededBehaviorProto {
UnsetBehavior = 0,
ThrowException = 1,
Block = 2,
Ignore = 3,
}Expand description
The behavior to take when the flow control limit is exceeded.
Variants
UnsetBehavior = 0
Default behavior, system-defined.
ThrowException = 1
Stop operation, raise error.
Block = 2
Pause operation until limit clears.
Ignore = 3
Continue operation, disregard limit.
Implementations
Sourceimpl FlowControlLimitExceededBehaviorProto
impl FlowControlLimitExceededBehaviorProto
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of FlowControlLimitExceededBehaviorProto.
Sourcepub fn from_i32(value: i32) -> Option<FlowControlLimitExceededBehaviorProto>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<FlowControlLimitExceededBehaviorProto>
Use the TryFrom<i32> implementation instead
Converts an i32 to a FlowControlLimitExceededBehaviorProto, or None if value is not a valid variant.
Sourceimpl FlowControlLimitExceededBehaviorProto
impl FlowControlLimitExceededBehaviorProto
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(
value: &str,
) -> Option<FlowControlLimitExceededBehaviorProto>
pub fn from_str_name( value: &str, ) -> Option<FlowControlLimitExceededBehaviorProto>
Creates an enum from field names used in the ProtoBuf definition.